@@ -5,7 +5,8 @@ import socket
 
 def get_ip():
     hostname = socket.gethostname()
-    if hostname != "idsd-2":
+    ip = socket.gethostbyname(hostname)
+    if ip[:2] != "10":
         return "172.17.0.1"
     else:
         return "10.10.0.1"
